Class: Google::Apis::AnalyticshubV1beta1::Listing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticshub_v1beta1/classes.rb,
lib/google/apis/analyticshub_v1beta1/representations.rb,
lib/google/apis/analyticshub_v1beta1/representations.rb

Overview

A listing is what gets published into a data exchange that a subscriber can subscribe to. It contains a reference to the data source along with descriptive information that will help subscribers find and subscribe the data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Listing

Returns a new instance of Listing.



834
835
836
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_only_metadata_sharingBoolean Also known as: allow_only_metadata_sharing?

Optional. If true, the listing is only available to get the resource metadata. Listing is non subscribable. Corresponds to the JSON property allowOnlyMetadataSharing

Returns:

  • (Boolean)


746
747
748
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 746

def 
  @allow_only_metadata_sharing
end

#bigquery_datasetGoogle::Apis::AnalyticshubV1beta1::BigQueryDatasetSource

A reference to a shared dataset. It is an existing BigQuery dataset with a collection of objects such as tables and views that you want to share with subscribers. When subscriber's subscribe to a listing, Analytics Hub creates a linked dataset in the subscriber's project. A Linked dataset is an opaque, read-only BigQuery dataset that serves as a symbolic link to a shared dataset. Corresponds to the JSON property bigqueryDataset



757
758
759
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 757

def bigquery_dataset
  @bigquery_dataset
end

#categoriesArray<String>

Optional. Categories of the listing. Up to five categories are allowed. Corresponds to the JSON property categories

Returns:

  • (Array<String>)


762
763
764
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 762

def categories
  @categories
end

#data_providerGoogle::Apis::AnalyticshubV1beta1::DataProvider

Contains details of the data provider. Corresponds to the JSON property dataProvider



767
768
769
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 767

def data_provider
  @data_provider
end

#descriptionString

Optional. Short description of the listing. The description must not contain Unicode non-characters and C0 and C1 control codes except tabs (HT), new lines (LF), carriage returns (CR), and page breaks (FF). Default value is an empty string. Max length: 2000 bytes. Corresponds to the JSON property description

Returns:

  • (String)


775
776
777
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 775

def description
  @description
end

#display_nameString

Required. Human-readable display name of the listing. The display name must contain only Unicode letters, numbers (0-9), underscores (_), dashes (-), spaces ( ), ampersands (&) and can't start or end with spaces. Default value is an empty string. Max length: 63 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


783
784
785
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 783

def display_name
  @display_name
end

#documentationString

Optional. Documentation describing the listing. Corresponds to the JSON property documentation

Returns:

  • (String)


788
789
790
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 788

def documentation
  @documentation
end

#iconString

Optional. Base64 encoded image representing the listing. Max Size: 3.0MiB Expected image dimensions are 512x512 pixels, however the API only performs validation on size of the encoded data. Note: For byte fields, the contents of the field are base64-encoded (which increases the size of the data by 33-36%) when using JSON on the wire. Corresponds to the JSON property icon NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


798
799
800
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 798

def icon
  @icon
end

#nameString

Output only. The resource name of the listing. e.g. projects/myproject/ locations/us/dataExchanges/123/listings/456 Corresponds to the JSON property name

Returns:

  • (String)


804
805
806
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 804

def name
  @name
end

#primary_contactString

Optional. Email or URL of the primary point of contact of the listing. Max Length: 1000 bytes. Corresponds to the JSON property primaryContact

Returns:

  • (String)


810
811
812
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 810

def primary_contact
  @primary_contact
end

#publisherGoogle::Apis::AnalyticshubV1beta1::Publisher

Contains details of the listing publisher. Corresponds to the JSON property publisher



815
816
817
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 815

def publisher
  @publisher
end

#request_accessString

Optional. Email or URL of the request access of the listing. Subscribers can use this reference to request access. Max Length: 1000 bytes. Corresponds to the JSON property requestAccess

Returns:

  • (String)


821
822
823
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 821

def request_access
  @request_access
end

#restricted_export_configGoogle::Apis::AnalyticshubV1beta1::RestrictedExportConfig

Restricted export config, used to configure restricted export on linked dataset. Corresponds to the JSON property restrictedExportConfig



827
828
829
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 827

def restricted_export_config
  @restricted_export_config
end

#stateString

Output only. Current state of the listing. Corresponds to the JSON property state

Returns:

  • (String)


832
833
834
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 832

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 839

def update!(**args)
  @allow_only_metadata_sharing = args[:allow_only_metadata_sharing] if args.key?(:allow_only_metadata_sharing)
  @bigquery_dataset = args[:bigquery_dataset] if args.key?(:bigquery_dataset)
  @categories = args[:categories] if args.key?(:categories)
  @data_provider = args[:data_provider] if args.key?(:data_provider)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @documentation = args[:documentation] if args.key?(:documentation)
  @icon = args[:icon] if args.key?(:icon)
  @name = args[:name] if args.key?(:name)
  @primary_contact = args[:primary_contact] if args.key?(:primary_contact)
  @publisher = args[:publisher] if args.key?(:publisher)
  @request_access = args[:request_access] if args.key?(:request_access)
  @restricted_export_config = args[:restricted_export_config] if args.key?(:restricted_export_config)
  @state = args[:state] if args.key?(:state)
end