Class: Google::Apis::AnalyticshubV1beta1::Subscription
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticshubV1beta1::Subscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticshub_v1beta1/classes.rb,
lib/google/apis/analyticshub_v1beta1/representations.rb,
lib/google/apis/analyticshub_v1beta1/representations.rb
Overview
A subscription represents a subscribers' access to a particular set of published data. It contains references to associated listings, data exchanges, and linked datasets.
Instance Attribute Summary collapse
-
#commercial_info ⇒ Google::Apis::AnalyticshubV1beta1::CommercialInfo
Commercial info metadata for this subscription.
-
#creation_time ⇒ String
Output only.
-
#data_exchange ⇒ String
Output only.
-
#destination_dataset ⇒ Google::Apis::AnalyticshubV1beta1::DestinationDataset
Defines the destination bigquery dataset.
-
#last_modify_time ⇒ String
Output only.
-
#linked_dataset_map ⇒ Hash<String,Google::Apis::AnalyticshubV1beta1::LinkedResource>
Output only.
-
#linked_resources ⇒ Array<Google::Apis::AnalyticshubV1beta1::LinkedResource>
Output only.
-
#listing ⇒ String
Output only.
-
#log_linked_dataset_query_user_email ⇒ Boolean
(also: #log_linked_dataset_query_user_email?)
Output only.
-
#name ⇒ String
Output only.
-
#organization_display_name ⇒ String
Output only.
-
#organization_id ⇒ String
Output only.
-
#resource_type ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#subscriber_contact ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Subscription
constructor
A new instance of Subscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Subscription
Returns a new instance of Subscription.
1290 1291 1292 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commercial_info ⇒ Google::Apis::AnalyticshubV1beta1::CommercialInfo
Commercial info metadata for this subscription.
Corresponds to the JSON property commercialInfo
1209 1210 1211 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1209 def commercial_info @commercial_info end |
#creation_time ⇒ String
Output only. Timestamp when the subscription was created.
Corresponds to the JSON property creationTime
1214 1215 1216 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1214 def creation_time @creation_time end |
#data_exchange ⇒ String
Output only. Resource name of the source Data Exchange. e.g. projects/123/
locations/us/dataExchanges/456
Corresponds to the JSON property dataExchange
1220 1221 1222 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1220 def data_exchange @data_exchange end |
#destination_dataset ⇒ Google::Apis::AnalyticshubV1beta1::DestinationDataset
Defines the destination bigquery dataset.
Corresponds to the JSON property destinationDataset
1225 1226 1227 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1225 def destination_dataset @destination_dataset end |
#last_modify_time ⇒ String
Output only. Timestamp when the subscription was last modified.
Corresponds to the JSON property lastModifyTime
1230 1231 1232 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1230 def last_modify_time @last_modify_time end |
#linked_dataset_map ⇒ Hash<String,Google::Apis::AnalyticshubV1beta1::LinkedResource>
Output only. Map of listing resource names to associated linked resource, e.g.
projects/123/locations/us/dataExchanges/456/listings/789 -> projects/123/
datasets/my_dataset For listing-level subscriptions, this is a map of size 1.
Only contains values if state == STATE_ACTIVE.
Corresponds to the JSON property linkedDatasetMap
1238 1239 1240 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1238 def linked_dataset_map @linked_dataset_map end |
#linked_resources ⇒ Array<Google::Apis::AnalyticshubV1beta1::LinkedResource>
Output only. Linked resources created in the subscription. Only contains
values if state = STATE_ACTIVE.
Corresponds to the JSON property linkedResources
1244 1245 1246 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1244 def linked_resources @linked_resources end |
#listing ⇒ String
Output only. Resource name of the source Listing. e.g. projects/123/locations/
us/dataExchanges/456/listings/789
Corresponds to the JSON property listing
1250 1251 1252 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1250 def listing @listing end |
#log_linked_dataset_query_user_email ⇒ Boolean Also known as: log_linked_dataset_query_user_email?
Output only. By default, false. If true, the Subscriber agreed to the email
sharing mandate that is enabled for DataExchange/Listing.
Corresponds to the JSON property logLinkedDatasetQueryUserEmail
1256 1257 1258 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1256 def log_linked_dataset_query_user_email @log_linked_dataset_query_user_email end |
#name ⇒ String
Output only. The resource name of the subscription. e.g. projects/myproject/
locations/us/subscriptions/123.
Corresponds to the JSON property name
1263 1264 1265 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1263 def name @name end |
#organization_display_name ⇒ String
Output only. Display name of the project of this subscription.
Corresponds to the JSON property organizationDisplayName
1268 1269 1270 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1268 def organization_display_name @organization_display_name end |
#organization_id ⇒ String
Output only. Organization of the project this subscription belongs to.
Corresponds to the JSON property organizationId
1273 1274 1275 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1273 def organization_id @organization_id end |
#resource_type ⇒ String
Output only. Listing shared asset type.
Corresponds to the JSON property resourceType
1278 1279 1280 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1278 def resource_type @resource_type end |
#state ⇒ String
Output only. Current state of the subscription.
Corresponds to the JSON property state
1283 1284 1285 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1283 def state @state end |
#subscriber_contact ⇒ String
Output only. Email of the subscriber.
Corresponds to the JSON property subscriberContact
1288 1289 1290 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1288 def subscriber_contact @subscriber_contact end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 |
# File 'lib/google/apis/analyticshub_v1beta1/classes.rb', line 1295 def update!(**args) @commercial_info = args[:commercial_info] if args.key?(:commercial_info) @creation_time = args[:creation_time] if args.key?(:creation_time) @data_exchange = args[:data_exchange] if args.key?(:data_exchange) @destination_dataset = args[:destination_dataset] if args.key?(:destination_dataset) @last_modify_time = args[:last_modify_time] if args.key?(:last_modify_time) @linked_dataset_map = args[:linked_dataset_map] if args.key?(:linked_dataset_map) @linked_resources = args[:linked_resources] if args.key?(:linked_resources) @listing = args[:listing] if args.key?(:listing) @log_linked_dataset_query_user_email = args[:log_linked_dataset_query_user_email] if args.key?(:log_linked_dataset_query_user_email) @name = args[:name] if args.key?(:name) @organization_display_name = args[:organization_display_name] if args.key?(:organization_display_name) @organization_id = args[:organization_id] if args.key?(:organization_id) @resource_type = args[:resource_type] if args.key?(:resource_type) @state = args[:state] if args.key?(:state) @subscriber_contact = args[:subscriber_contact] if args.key?(:subscriber_contact) end |